# ExternalAPIWaybillTransportCostsPricingSystem

The price used to calculate the transport cost.  * `coefficient_price` - Coefficient price * `ton_price` - Ton price * `mileage_price` - Mileage price * `load_price` - Load price

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from openapi_client.models.external_api_waybill_transport_costs_pricing_system import ExternalAPIWaybillTransportCostsPricingSystem

# TODO update the JSON string below
json = "{}"
# create an instance of ExternalAPIWaybillTransportCostsPricingSystem from a JSON string
external_api_waybill_transport_costs_pricing_system_instance = ExternalAPIWaybillTransportCostsPricingSystem.from_json(json)
# print the JSON string representation of the object
print(ExternalAPIWaybillTransportCostsPricingSystem.to_json())

# convert the object into a dict
external_api_waybill_transport_costs_pricing_system_dict = external_api_waybill_transport_costs_pricing_system_instance.to_dict()
# create an instance of ExternalAPIWaybillTransportCostsPricingSystem from a dict
external_api_waybill_transport_costs_pricing_system_from_dict = ExternalAPIWaybillTransportCostsPricingSystem.from_dict(external_api_waybill_transport_costs_pricing_system_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


